﻿using IdProtectorExample.Models;
using Microsoft.AspNetCore.DataProtection;
using Microsoft.AspNetCore.Mvc;
using System.Collections.Generic;
using System.Linq;

namespace IdProtectorExample.Controllers
{
    [Route("api/[controller]")]
    public class MoviesController : ControllerBase
    {
        private readonly IDataProtector protector;

        public MoviesController(IDataProtectionProvider provider)
        {
            this.protector = provider.CreateProtector("protect_my_query_string");
        }

        // GET api/values
        [HttpGet]
        public IActionResult Get()
        {
            var model = GetMovies(); // simulate call to repository

            var outputModel = model.Select(item => new
            {
                Id = this.protector.Protect(item.Id.ToString()),
                item.Title
            });

            return Ok(outputModel);
        }

        // GET api/values/5
        [HttpGet("{id}")]
        [DecryptReference]
        public IActionResult Get(int id)
        {
            var model = GetMovies();

            var outputModel = model.Where(item => item.Id == id);

            return Ok(outputModel);
        }

        private List<Movie> GetMovies()
        {
            var movies = new List<Movie> {
                new Movie(1, "泰坦尼克号"),
                new Movie(2, "我是谁"),
                new Movie(3, "蜘蛛侠"),
                new Movie(4, "钢铁侠"),
            };

            return movies;
        }
    }
}
